==> mili-4.2.4.tgz: package/es/src/check.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as fs from 'fs-extra';
import { render } from "./render";
import { createTmpDir } from "./util/create-tmp-dir";
import { parseTemplate } from "./util/parse-template";
import { diff } from "./diff";
import { copy } from "./util/copy";
export function check(options) {
    return __awaiter(this, void 0, void 0, function* () {
        const { template, version = 'latest', cwd = process.cwd(), showDiff = false, fold = false, answers = {}, } = options;
        const tmpDir = yield createTmpDir();
        yield copy(cwd, tmpDir, true);
        const repository = parseTemplate(template, version);
        yield render(tmpDir, repository, answers);
        const errs = yield diff(cwd, tmpDir, { fold, showDiff });
        yield fs.remove(tmpDir);
        if (errs.length)
            throw new Error('Check Failed');
    });
}

==> mili-4.5.1.tgz: package/es/src/check.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as fs from 'fs-extra';
import { render } from "./render";
import { createTmpDir } from "./util/create-tmp-dir";
import { parseTemplate } from "./util/parse-template";
import { diff } from "./diff";
import { copy } from "./util/copy";
export function check(options) {
    return __awaiter(this, void 0, void 0, function* () {
        const { template, version = 'latest', registry, cwd = process.cwd(), showDiff = false, fold = false, answers = {}, } = options;
        const tmpDir = yield createTmpDir();
        yield copy(cwd, tmpDir, true);
        const repository = parseTemplate(template, version, registry);
        const resource = { mili: { operation: 'check' } };
        yield render(tmpDir, repository, answers, resource);
        const errs = yield diff(cwd, tmpDir, { fold, showDiff });
        yield fs.remove(tmpDir);
        if (errs.length)
            throw new Error('Check Failed');
    });
}
